@@ -1,8 +1,8 @@
-from xkcd import xkcd
+from xkcd_python.xkcd import xkcd
 
 Client = xkcd
 
-__version__ = '2.6.0'
+__version__ = '2.7.0'
 __author__ = "Sasen Perera"
 __shot_des__ = "A python wrapper for xkcd.com"
 __description__ = "A wrapper for xkcd.com's API. Built Using Python."
\ No newline at end of file
